Class: RubyMVC::Views::TableView
- Inherits:
-
View
- Object
- Toolkit::AbstractWidget
- View
- RubyMVC::Views::TableView
- Defined in:
- lib/ruby_mvc/views/table_view.rb
Instance Attribute Summary
Attributes inherited from View
Instance Method Summary collapse
-
#initialize(model, options = {}, &block) ⇒ TableView
constructor
A new instance of TableView.
-
#load(model, options = {}, &block) ⇒ Object
This method is used to load the view with the information in the table model.
Methods included from Toolkit::SignalHandler::ClassMethods
#signal, #signals, #valid_signal!, #valid_signal?
Methods included from Toolkit::SignalHandler
#signal_connect, #signal_disconnect, #signal_emit
Constructor Details
#initialize(model, options = {}, &block) ⇒ TableView
Returns a new instance of TableView.
30 31 32 33 |
# File 'lib/ruby_mvc/views/table_view.rb', line 30 def initialize(model, = {}, &block) super(, &block) load(model, , &block) end |
Instance Method Details
#load(model, options = {}, &block) ⇒ Object
This method is used to load the view with the information in the table model.
38 39 |
# File 'lib/ruby_mvc/views/table_view.rb', line 38 def load(model, = {}, &block) end |