Class: RubyMVC::Views::WebContentView
- Inherits:
-
View
- Object
- Toolkit::AbstractWidget
- View
- RubyMVC::Views::WebContentView
- Defined in:
- lib/ruby_mvc/views/web_content_view.rb
Overview
WebContentView instances are used to render models as web content to be displayed in either the Toolkit::WebView or the Views::BrowserView instances.
Direct Known Subclasses
Instance Attribute Summary collapse
-
#uri ⇒ Object
readonly
Returns the value of attribute uri.
Attributes inherited from View
Attributes included from ActionProvider
Instance Method Summary collapse
-
#initialize(model, options = {}) ⇒ WebContentView
constructor
A new instance of WebContentView.
- #render ⇒ Object
Methods included from ActionProvider
Methods included from Toolkit::SignalHandler::ClassMethods
#signal, #signals, #valid_signal!, #valid_signal?
Methods included from Toolkit::SignalHandler
#signal_connect, #signal_disconnect, #signal_emit
Constructor Details
#initialize(model, options = {}) ⇒ WebContentView
Returns a new instance of WebContentView.
36 37 38 39 40 |
# File 'lib/ruby_mvc/views/web_content_view.rb', line 36 def initialize(model, = {}) super() @model = model @uri = [:uri] end |
Instance Attribute Details
#uri ⇒ Object (readonly)
Returns the value of attribute uri.
34 35 36 |
# File 'lib/ruby_mvc/views/web_content_view.rb', line 34 def uri @uri end |
Instance Method Details
#render ⇒ Object
42 43 |
# File 'lib/ruby_mvc/views/web_content_view.rb', line 42 def render end |