Class: RubyMVC::Toolkit::WxRuby::Frame
- Inherits:
-
Wx::Frame
- Object
- Wx::Frame
- RubyMVC::Toolkit::WxRuby::Frame
- Includes:
- Common
- Defined in:
- lib/ruby_mvc/toolkit/peers/wxruby/frame.rb
Instance Method Summary collapse
-
#add(child, options = {}) ⇒ Object
This method is used to add a child to the existing frame.
-
#initialize(options) ⇒ Frame
constructor
A new instance of Frame.
Methods included from Common
Constructor Details
#initialize(options) ⇒ Frame
Returns a new instance of Frame.
33 34 35 36 37 38 |
# File 'lib/ruby_mvc/toolkit/peers/wxruby/frame.rb', line 33 def initialize() opts = {} opts[:title] = [:title] opts[:size] = [ [:width], [:height] ] super([:parent], opts) end |
Instance Method Details
#add(child, options = {}) ⇒ Object
This method is used to add a child to the existing frame.
43 44 45 |
# File 'lib/ruby_mvc/toolkit/peers/wxruby/frame.rb', line 43 def add(child, = {}) child.peer.reparent(self) end |